from . import DSTWorld, DSTWeb

"""
Don't Starve Together World Registration

This file contains the metadata and class references for the dontstarvetogether world.
"""

# Required metadata
WORLD_NAME = "dontstarvetogether"

from BaseUtils import get_archipelago_json
game_name, author, minimum_ap_version, version = get_archipelago_json(WORLD_NAME)

GAME_NAME = game_name
AUTHOR = author
VERSION = version

# Plugin entry points
WORLD_CLASS = DSTWorld
WEB_WORLD_CLASS = DSTWeb
CLIENT_FUNCTION = None
